Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(48)

Unified Diff: tools/gyp_dart.py

Issue 11184008: Change Windows build default to build with VS 2010. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/build.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gyp_dart.py
===================================================================
--- tools/gyp_dart.py (revision 13701)
+++ tools/gyp_dart.py (working copy)
@@ -22,9 +22,9 @@
'-Idart/tools/gyp/all.gypi', 'dart/dart.gyp']
if sys.platform == 'win32':
# Generate Visual Studio 2008 compatible files by default.
if not os.environ.get('GYP_MSVS_VERSION'):
- args.extend(['-G', 'msvs_version=2008'])
+ args.extend(['-G', 'msvs_version=2010'])
sys.exit(execute(args))
« no previous file with comments | « tools/build.py ('k') | no next file » | no next file with comments »
@@ -22,9 +22,9 @@
'-Idart/tools/gyp/all.gypi', 'dart/dart.gyp']
if sys.platform == 'win32':
- # Generate Visual Studio 2008 compatible files by default.
+ # Generate Visual Studio 2010 compatible files by default.
if not os.environ.get('GYP_MSVS_VERSION'):

Powered by Google App Engine
This is Rietveld 408576698